
/***********************************************************************/
/* netutils.c -- This contains some useful little network/socket        */
/* related utility functions.                                          */
/*                                                                     */
/***********************************************************************/
/*  The nsock parallel socket event library is (C) 2000 Insecure.Com   */
/*  LLC This library is free software; you can redistribute it and/or  */
/*  modify it under the terms of the GNU General Public License as     */
/*  published by the Free Software Foundation; Version 2.  This        */
/*  guarantees your right to use, modify, and redistribute this        */
/*  software under certain conditions.  If this license is             */
/*  unacceptable to you, Insecure.Com LLC may be willing to sell       */
/* alternative licenses (contact fyodor@insecure.org ).                */
/*                                                                     */
/*  If you received these files with a written license agreement       */
/*  stating terms other than the (GPL) terms above, then that          */
/*  alternative license agreement takes precendence over this comment. */
/*                                                                     */
/*  Source is provided to this software because we believe users have  */
/*  a right to know exactly what a program is going to do before they  */
/*  run it.  This also allows you to audit the software for security   */
/*  holes (none have been found so far).                               */
/*                                                                     */
/*  Source code also allows you to port nsock to new platforms, fix    */
/*  bugs, and add new features.  You are highly encouraged to send     */
/*  your changes to Fyodor for possible incorporation into the main    */
/*  distribution.  By sending these changes to Fyodor or one the       */
/*  insecure.org development mailing lists, it is assumed that you     */
/*  are offering Fyodor the unlimited, non-exclusive right to reuse,   */
/*  modify, and relicense the code.  If you wish to specify special    */
/*  license conditions of your contributions, please state them up     */
/*  front.                                                             */
/*                                                                     */
/*  This program is distributed in the hope that it will be useful,    */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of     */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU  */
/*  General Public License for more details (                          */
/*  http://www.gnu.org/copyleft/gpl.html ).                            */
/*                                                                     */
/***********************************************************************/

/* $Id: netutils.c,v 1.2 2000/07/06 12:11:03 fyodor Exp $ */

#include "netutils.h"
#include "error.h"

#include <sys/time.h>
#include <sys/resource.h>
#include <unistd.h>
#include <netinet/in.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <fcntl.h>

static int netutils_debugging = 0;

/* maximize the number of file descriptors (including sockets) allowed
   for this process and return that maximum value (note -- you better
   not actually open this many -- stdin, stdout, other files opened by
   libraries you use, etc. all count toward this limit.  Leave a
   little slack */

int maximize_fdlimit() { 

struct rlimit r; 
static int maxfds = -1;

  if (maxfds > 0)
    return maxfds;

#if(defined(RLIMIT_NOFILE))
  if (!getrlimit(RLIMIT_NOFILE, &r)) {
    r.rlim_cur = r.rlim_max;
    if (setrlimit(RLIMIT_NOFILE, &r))
      if (netutils_debugging) perror("setrlimit RLIMIT_NOFILE failed");
    if (!getrlimit(RLIMIT_NOFILE, &r)) {
      maxfds = r.rlim_cur;
      return maxfds;
    } else return 0;
  }
#endif
#if(defined(RLIMIT_OFILE) && !defined(RLIMIT_NOFILE))
  if (!getrlimit(RLIMIT_OFILE, &r)) {
    r.rlim_cur = r.rlim_max;
    if (setrlimit(RLIMIT_OFILE, &r))
      if (netutils_debugging) perror("setrlimit RLIMIT_OFILE failed");
    if (!getrlimit(RLIMIT_OFILE, &r)) {
      maxfds = r.rlim_cur;
      return maxfds;
    } else return 0;
  }
#endif
  return 0;
}



int unblock_socket(int sd) {
int options;
/*Unblock our socket to prevent recvfrom from blocking forever
  on certain target ports. */
options = O_NONBLOCK | fcntl(sd, F_GETFL);
fcntl(sd, F_SETFL, options);
return 1;
}

